@@ -70,25 +70,38 @@ class Account(Entity):
 
         return self.get_device(response.get("device"))
 
-    def get_device(self, device_id):
+    def get_device(self, device_id, params=None):
         """:obj:`Device`: Fetch an device by its device ID (Dxxxxxxxxxxxx).
 
         Args:
             device_id (str): Device ID.
+            params (dict): Optional query parameters.
         """
 
-        device_data = self.api.call("GET", "/accounts/{}/devices/{}".format(self._id, device_id))
+        device_data = self.api.call(
+            "GET",
+            "/accounts/{}/devices/{}".format(self._id, device_id),
+            params=params,
+        )
         if not device_data:
             return None
 
         device = Device(device_data["device"], device_data, api=self.api)
         return device
 
-    def get_devices(self, attributes=None, zones=None, include_subzones=None):
+    def get_devices(self, attributes=None, zones=None, include_subzones=None, params=None):
         """:obj:`list` of :obj:`Device`: Fetch a list of all devices in the account.
+
+        Args:
+            device_id (str): Device ID.
+            attributes (list): Optional list of device attributes to return.
+            attributes (zones): Optional list of zones to filter.
+            include_subzones (zones): Optional list of subzones to filter.
+            params (dict): Optional query parameters.
         """
 
-        params = {}
+        if params is None:
+            params = {}
         if attributes is not None:
             params["attributes"] = json.dumps(attributes)
         if zones is not None:
@@ -101,10 +114,17 @@ class Account(Entity):
             raise ValueError("API returned incorrect type")
         return [Device(device_data["device"], device_data, api=self.api) for device_data in result]
 
-    def get_zones(self):
+    def get_zones(self, params=None):
         """:obj:`list` of :obj:`Zone`: Fetch a list of all zones in the account.
+
+        Args:
+            params (dict): Optional query parameters.
         """
-        result = self.api.call("GET", "/accounts/{}/zones".format(self._id))
+        result = self.api.call(
+            "GET",
+            "/accounts/{}/zones".format(self._id),
+            params=params,
+        )
         if not result:
             return []
         return [Zone(data['id'], data, api=self.api) for data in result]
@@ -139,7 +159,7 @@ class Account(Entity):
         """
         return self._data.get("name")
 
-    def get_statistics_csv(self, utc_start=None, utc_end=None, **params):
+    def get_statistics_csv(self, utc_start=None, utc_end=None, params=None):
         """Gets all the statistics for an account in a CSV format.
 
         Args:
@@ -147,11 +167,13 @@ class Account(Entity):
                 If null, returns the API default range (1 day).
             utc_end (float): Returns statistics until the specified timestamp (inclusive).
                 If null, returns the statistics until current hour.
-            **params: Extra parameters that could be included in the request.
+            params (dict): Extra parameters that could be included in the request.
 
         Returns:
             String object with the CSV content.
         """
+        if params is None:
+            params = {}
         if utc_start is not None:
             params['utc_start'] = utc_start
         if utc_end is not None:
