@@ -27,11 +27,33 @@ def api_call(*args, **kwargs):
 
 class APIHandler(object):
 
-    def __init__(self, token=None, secret=None, url=DEFAULT_URL, retry_config={}):
+    def __init__(self,
+            token=None,
+            secret=None,
+            url=DEFAULT_URL,
+            retry_config=None,
+            profiler=False,
+            profiler_min_duration=1):
+        """Class that perform all the requests to the API
+
+        Args:
+            token (str): API token. Can be a session or user token.
+            secret (str): API secret.
+            url (str): Optional url to point to a specific API.
+            retry_config (dict): Configuration for requests retry.
+                By default it will use the usual requests configuration
+            profiler (bool): If enabled, will enable the profiler on all API requests.
+            profiler_min_duration (float/int): If profiler is enabled, will add the min duration
+                for a profile results to be dumped on the API side.
+        """
         self.token = token
         self.secret = secret
         self.url = url
+        if retry_config is None:
+            retry_config = {}
         self.retry_config = retry_config
+        self.profiler = profiler
+        self.profiler_min_duration = profiler_min_duration
 
     def get_session(self):
         session = requests.Session()
@@ -102,6 +124,11 @@ class APIHandler(object):
                 "mc_token": self.token,
                 "mc_secret": self.secret,
             }
+        if self.profiler:
+            if params is None:
+                params = {}
+            params['profiler'] = 'enable'
+            params['profiler_min_duration'] = self.profiler_min_duration
 
         url = self.url.strip("/") + "/" + path.strip("/")
         if method == "GET":
